@@ -47,12 +47,11 @@ import org.junit.Test;
 
 /**
  * Simple test to ensure that the generated bindings are working.
- * 
- * @author Murray Cumming, Ben Konrath
  */
 public class DocumentTest {
 
 	private static Document document;
+	private static String locale = ""; //This means the original locale.
 
 	@BeforeClass
 	static public void setUp() {
@@ -95,10 +94,10 @@ public class DocumentTest {
 		assertEquals(6, fields.size());
 
 		Field field = fields.get(0);
-		String titles = field.get_title_or_name();
+		String titles = field.get_title_or_name(locale);
 		for (int i = 1; i < fields.size(); i++) {
 			field = fields.get(i);
-			titles += ", " + field.get_title_or_name();
+			titles += ", " + field.get_title_or_name(locale);
 		}
 		assertThat(titles, is("Album ID, Comments, Name, Artist ID, Publisher ID, Year"));
 
@@ -106,10 +105,10 @@ public class DocumentTest {
 		assertEquals(4, fields.size());
 
 		field = fields.get(0);
-		titles = field.get_title_or_name();
+		titles = field.get_title_or_name(locale);
 		for (int i = 1; i < fields.size(); i++) {
 			field = fields.get(i);
-			titles += ", " + field.get_title_or_name();
+			titles += ", " + field.get_title_or_name(locale);
 		}
 		assertThat(titles, is("Artist ID, Description, Comments, Name"));
 
@@ -117,10 +116,10 @@ public class DocumentTest {
 		assertEquals(3, fields.size());
 
 		field = fields.get(0);
-		titles = field.get_title_or_name();
+		titles = field.get_title_or_name(locale);
 		for (int i = 1; i < fields.size(); i++) {
 			field = fields.get(i);
-			titles += ", " + field.get_title_or_name();
+			titles += ", " + field.get_title_or_name(locale);
 		}
 		assertThat(titles, is("Publisher ID, Comments, Name"));
 
@@ -128,10 +127,10 @@ public class DocumentTest {
 		assertEquals(4, fields.size());
 
 		field = fields.get(0);
-		titles = field.get_title_or_name();
+		titles = field.get_title_or_name(locale);
 		for (int i = 1; i < fields.size(); i++) {
 			field = fields.get(i);
-			titles += ", " + field.get_title_or_name();
+			titles += ", " + field.get_title_or_name(locale);
 		}
 		assertThat(titles, is("Song ID, Comments, Album ID, Name"));
 	}
